==> cherishedworlds-fabric-6.0.1+1.19.2.jar: CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/) and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).
Prior to version 6.0.0, this project used MCVERSION-MAJORMOD.MAJORAPI.MINOR.PATCH.

## [6.0.1+1.19.2] - 2022.08.10
### Changed
- Updated to Minecraft 1.19.2
- [Forge] Updated to Forge 43+
- [Fabric] Updated to Fabric API 0.59.0+
### Fixed
- Fixed world selection list not updating when saving/removing favorites

## [6.0.0+1.19.1] - 2022.07.29
### Changed
- Updated to Minecraft 1.19.1
- [Forge] Updated to Forge 42.0.0 or above
- [Fabric] Updated to Fabric API 0.58.5 or above

## [6.0.0-beta.3+1.19] - 2022.07.10
### Changed
- [Forge] Updated to and requires Forge 41.0.64 or above

## [6.0.0-beta.2+1.19] - 2022.07.02
### Fixed
- Fixed potential `ClassCastException` crash when loading world list

## [6.0.0-beta.1+1.19] - 2022.07.02
### Changed
- Merged Forge and Fabric versions of the project together using the MultiLoader template
- Changed to [Semantic Versioning](http://semver.org/spec/v2.0.0.html)
- Favorites are now saved to the root instance folder as `cherishedworlds-favorites.dat` instead of to the `config` folder
- Updated to Minecraft 1.19
- [Forge] Updated to Forge 41+
- [Fabric] Updated to Fabric API 0.55.2+

## [1.18-5.1.1.0] - 2021.12.02
### Added
- Added Italian localization (thanks ghost!) [#11](https://github.com/TheIllusiveC4/CherishedWorlds/pull/11)
### Changed
- Updated to Minecraft 1.18
- Updated to Forge 38+

## [1.17.1-5.1.1.0] - 2021.09.16
### Changed
- Updated to Minecraft 1.17.1
- Updated to Forge 37.+

## [1.16.5-5.1.1.0] - 2021.07.01
### Added
- Added feature to favorite servers

## [1.16.4-5.1.0.0] - 2020.11.16
### Added
- Added French translation (thanks Lykrast!)
### Changed
- Updated to Minecraft 1.16.4

## [1.16.3-5.0.0.1] - 2020.09.28
### Changed
- Updated to Minecraft 1.16.3

## [1.16.2-5.0.0.0] - 2020.08.16
### Added
- Added Chinese translation (thanks BlueskyClouds!)
- Added Croatian translation (thanks COMBOhrenovke!)
### Changed
- Updated to Minecraft 1.16.2

## [1.16.1-4.0.0.1] - 2020.07.29
### Added
- Added Brazilian localization (thanks Felipe23f!)

## [1.16.1-4.0.0.0] - 2020.07.03
### Changed
- Ported to 1.16.1 Forge

## [1.15.2-3.0.0.1] - 2020.07.03
### Added
- Added Russian localization (thanks BardinTheDwarf!)

## [1.15.2-3.0.0.0] - 2020.02.14
### Changed
- Ported to 1.15.2 Forge

## [1.14.4-2.0.0.0] - 2019.09.14
### Changed
- Updated to Forge 28.1.0+

## [1.14.4-2.0.0.0-beta3] - 2019.09.07
### Fixed
- Fixed crashing when selecting worlds [#1](https://github.com/TheIllusiveC4/CherishedWorlds/issues/1)

## [1.14.4-2.0.0.0-beta2] - 2019.09.07
### Changed
- Updated to Minecraft 1.14.4

## [1.13.2-2.0.0.0-beta1] - 2019.04.29
### Changed
- Updated to Minecraft 1.13.2
- Changed pin/unpin button functions to simply clicking the star icon

## [1.12.2-1.0.0.0] - 2018.12.02
- Initial release

==> cherishedworlds-fabric-6.1.3+1.20.1.jar: CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/) and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).
Prior to version 6.0.0, this project used MCVERSION-MAJORMOD.MAJORAPI.MINOR.PATCH.

## [6.1.3+1.20.1] - 2023.10.26
### Fixed
- Fixed crashes when swapping servers on the server list with mods that edit the server screen [#25](https://github.com/illusivesoulworks/cherishedworlds/issues/25)

## [6.1.2+1.20.1] - 2023.09.08
### Added
- Added `be_by` localization (thanks Gazmanovich!) [#23](https://github.com/illusivesoulworks/cherishedworlds/pull/23)
### Fixed
- Fixed `tt_ru` localization (thanks Amirhan-Taipovjan-Greatest-I!) [#24](https://github.com/illusivesoulworks/cherishedworlds/pull/24)

## [6.1.1+1.20.1] - 2023.07.14
### Added
- Added `tt_ru` localization (thanks Amirhan-Taipovjan-Greatest-I!) [#22](https://github.com/illusivesoulworks/cherishedworlds/pull/22)

## [6.1.0+1.20.1] - 2023.06.16
### Changed
- Updated to Minecraft 1.20.1

## [6.0.5+1.19.4] - 2023.04.20
### Added
- Added `uk_ua` localization (thanks Tema_Hromosoma!)

## [6.0.4+1.19.4] - 2023.03.17
### Changed
- Updated to Minecraft 1.19.4

## [6.0.4+1.19.3] - 2023.03.08
### Added
- Added `zh_tw` localization (thanks notlin4!) [#19](https://github.com/illusivesoulworks/cherishedworlds/pull/19)

## [6.0.3+1.19.3] - 2023.02.17
### Fixed
- [Quilt] Fixed mixin crashes on startup [#18](https://github.com/illusivesoulworks/cherishedworlds/issues/18)

## [6.0.2+1.19.3] - 2022.12.18
### Added
- Added Quilt support
### Changed
- Updated to Minecraft 1.19.3
- [Forge] Updated to Forge 44+
- [Fabric] Updated to Fabric API 0.69.0+

## [6.0.1+1.19.2] - 2022.08.10
### Changed
- Updated to Minecraft 1.19.2
- [Forge] Updated to Forge 43+
- [Fabric] Updated to Fabric API 0.59.0+
### Fixed
- Fixed world selection list not updating when saving/removing favorites

## [6.0.0+1.19.1] - 2022.07.29
### Changed
- Updated to Minecraft 1.19.1
- [Forge] Updated to Forge 42.0.0 or above
- [Fabric] Updated to Fabric API 0.58.5 or above

## [6.0.0-beta.3+1.19] - 2022.07.10
### Changed
- [Forge] Updated to and requires Forge 41.0.64 or above

## [6.0.0-beta.2+1.19] - 2022.07.02
### Fixed
- Fixed potential `ClassCastException` crash when loading world list

## [6.0.0-beta.1+1.19] - 2022.07.02
### Changed
- Merged Forge and Fabric versions of the project together using the MultiLoader template
- Changed to [Semantic Versioning](http://semver.org/spec/v2.0.0.html)
- Favorites are now saved to the root instance folder as `cherishedworlds-favorites.dat` instead of to the `config` folder
- Updated to Minecraft 1.19
- [Forge] Updated to Forge 41+
- [Fabric] Updated to Fabric API 0.55.2+

## [1.18-5.1.1.0] - 2021.12.02
### Added
- Added Italian localization (thanks ghost!) [#11](https://github.com/TheIllusiveC4/CherishedWorlds/pull/11)
### Changed
- Updated to Minecraft 1.18
- Updated to Forge 38+

## [1.17.1-5.1.1.0] - 2021.09.16
### Changed
- Updated to Minecraft 1.17.1
- Updated to Forge 37.+

## [1.16.5-5.1.1.0] - 2021.07.01
### Added
- Added feature to favorite servers

## [1.16.4-5.1.0.0] - 2020.11.16
### Added
- Added French translation (thanks Lykrast!)
### Changed
- Updated to Minecraft 1.16.4

## [1.16.3-5.0.0.1] - 2020.09.28
### Changed
- Updated to Minecraft 1.16.3

## [1.16.2-5.0.0.0] - 2020.08.16
### Added
- Added Chinese translation (thanks BlueskyClouds!)
- Added Croatian translation (thanks COMBOhrenovke!)
### Changed
- Updated to Minecraft 1.16.2

## [1.16.1-4.0.0.1] - 2020.07.29
### Added
- Added Brazilian localization (thanks Felipe23f!)

## [1.16.1-4.0.0.0] - 2020.07.03
### Changed
- Ported to 1.16.1 Forge

## [1.15.2-3.0.0.1] - 2020.07.03
### Added
- Added Russian localization (thanks BardinTheDwarf!)

## [1.15.2-3.0.0.0] - 2020.02.14
### Changed
- Ported to 1.15.2 Forge

## [1.14.4-2.0.0.0] - 2019.09.14
### Changed
- Updated to Forge 28.1.0+

## [1.14.4-2.0.0.0-beta3] - 2019.09.07
### Fixed
- Fixed crashing when selecting worlds [#1](https://github.com/TheIllusiveC4/CherishedWorlds/issues/1)

## [1.14.4-2.0.0.0-beta2] - 2019.09.07
### Changed
- Updated to Minecraft 1.14.4

## [1.13.2-2.0.0.0-beta1] - 2019.04.29
### Changed
- Updated to Minecraft 1.13.2
- Changed pin/unpin button functions to simply clicking the star icon

## [1.12.2-1.0.0.0] - 2018.12.02
- Initial release
